==> qtstalker_0.26.orig.tar.gz: qtstalker-0.26/plugins/quote/CME/CME.h <==
/*
 *  Qtstalker stock charter
 *
 *  Copyright (C) 2001-2004 Stefan S. Stratigakos
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 */

#include "QuotePlugin.h"
#include "FuturesData.h"
#include "Setting.h"
#include <qstring.h>
#include <qnetworkprotocol.h>
#include <qurloperator.h>
#include <qcombobox.h>

class CME : public QuotePlugin
{
  Q_OBJECT

  public:
    CME ();
    virtual ~CME ();
    void update ();
    void parseToday ();
    void saveTodayData (QStringList);
    void parse (Setting *);
    void cancelUpdate ();
    void loadSettings ();
    void saveSettings ();
    void prefDialog ();
    void parseHistory ();

  public slots:
    void getFile ();
    void getFileHistory ();
    void opDone (QNetworkOperation *);
    void opHistoryDone (QNetworkOperation *);
    void methodChanged (const QString &);

  private:
    FuturesData fd;
    QUrlOperator *op;
    QStringList urlList;
    int symbolLoop;
    QString file2;
    QUrlOperator opHistory;
    QString url;
    QString currentSymbol;
    QString method;
    QComboBox *symbolCombo;
};

extern "C"
{
  Plugin * create ();
}

==> qtstalker-0.36.tar.gz: qtstalker-0.36/plugins/quote/CME/CME.h <==
/*
 *  Qtstalker stock charter
 *
 *  Copyright (C) 2001-2007 Stefan S. Stratigakos
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 */

#include "QuotePlugin.h"
#include "FuturesData.h"
#include "Setting.h"
#include <qstring.h>
#include <qcombobox.h>
#include "DbPlugin.h"
#include "Config.h"

class CME : public QuotePlugin
{
  Q_OBJECT

  public:
    CME ();
    virtual ~CME ();
    void update ();
    void parseToday ();
    void parseHistory ();
    void saveTodayData (QStringList &);
    void parse (Setting &);
    void cancelUpdate ();
    void loadSettings ();
    void saveSettings ();
    void buildGui ();

  public slots:
    void methodChanged (const QString &);
    void startDownload ();
    void fileDone (QString);
    void timeoutError ();

  private:
    FuturesData fd;
    QStringList urlList;
    int symbolLoop;
    QString file2;
    QComboBox *symbolCombo;
    QComboBox *methodCombo;
    QStringList symbolList;
    bool allSymbols;
    int downloadIndex;
    bool cancelFlag;
    DbPlugin plug;
    QStringList methodList;
    Config config;
};

extern "C"
{
  QuotePlugin * createQuotePlugin ();
}
